@@ -6,12 +6,11 @@ use Log::Dispatch::Email;
 
 use base qw( Log::Dispatch::Email );
 
-use Carp ();
 use MIME::Lite;
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.19 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = '1.19';
 
 1;
 
@@ -28,6 +27,7 @@ sub send_email
 
     $mail{From} = $self->{from} if defined $self->{from};
 
+    local $?;
     unless ( MIME::Lite->new(%mail)->send )
     {
 	warn "Error sending mail with MIME::Lite" if $^W;
@@ -76,12 +76,12 @@ The name of the object (not the filename!).  Required.
 =item * min_level ($)
 
 The minimum logging level this object will accept.  See the
-Log::Dispatch documentation for more information.  Required.
+Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  Required.
 
 =item * max_level ($)
 
 The maximum logging level this obejct will accept.  See the
-Log::Dispatch documentation for more information.  This is not
+Log::Dispatch documentation on L<Log Levels|Log::Dispatch/"Log Levels"> for more information.  This is not
 required.  By default the maximum is the highest possible level (which
 means functionally that the object has no maximum).
 
